@echo OFF
REM FL1B.BAT  W7PUA 6 May 2013
REM Basically this BAT is the "UHF3X.BAT" as written by KD7TS, with
REM changes to the handling of the command line.
REM This is a decendent of FL1.BAT and the purpose is to take the
REM contents of an Intel hex file and place the program into Bank 1
REM of the DSPx flash memory.
REM Command line:         FL1B n FILENAME.HEX    n=COM port,
REM Command Line example: FL1B 2 UHF3X35B.HEX
REM If n=0, this program will attempt to find the COM port.
	echo FL1B.BAT - Loads DSPx Flash Bank 1, with a DSP  program such as
	echo UHF3Xzzz.HEX for the DSP-10.
	echo.
	IF NOT EXIST EZLD.COM echo File EZLD.COM not found.
	IF NOT EXIST EZLD.COM GOTO splash
	IF NOT EXIST FLASHUTB.EXE echo File FLASHUTB.EXE not found.
	IF NOT EXIST FLASHUTB.EXE GOTO splash
	IF NOT EXIST XFINDMN1.EXE echo File XFINDMN1.EXE not found.
	IF NOT EXIST XFINDMN1.EXE GOTO splash
	IF NOT EXIST XFLASH1.EXE echo File XFLASH1.EXE not found.
	IF NOT EXIST XFLASH1.EXE GOTO splash
	IF "%2"=="" echo Missing file name in FL1B command line.
	IF "%2"=="" GOTO splash
	IF NOT EXIST %2 echo File %2 not found.
	IF NOT EXIST %2 GOTO err_bsp
	
:testports
	set el=99
	echo Checking ports and DSPx
	REM XFINDMN1 identifies DSP-10 functions for COM ports
	XFINDMN1
	REM  XFINDMN1 returns a value to ERRORLEVEL:
	REM      0    No DSPx program found
	REM      1+p  Program on COM1  
	REM      2+p  Program on COM2
	REM      3+p  Program on COM3
	REM      4+p  Program on COM4
	REM      where p=0 for Monitor program
	REM            p=4 for FLASHUTx program
	REM            p=8 for DSP-10 UHF3 program
	
	REM  UHF3 running
	REM %XX% is the value of the environmemtal variable XX
	REM If "SET XX=3" was executed in DOS, then %XX% would be 3
	IF ERRORLEVEL 12 SET el=4
	IF %el%==4 GOTO  err_uhf3
	IF ERRORLEVEL 11 SET el=3
	IF %el%==3 GOTO  err_uhf3
	IF ERRORLEVEL 10 SET el=2
	IF %el%==2 GOTO  err_uhf3
	IF ERRORLEVEL 9 SET el=1
	IF %el%==1 GOTO  err_uhf3
	
	REM flash util running
	IF ERRORLEVEL 8 SET el=4
	IF %el%==4 GOTO err_flutl
	IF ERRORLEVEL 7 SET el=3
	IF %el%==3 GOTO err_flutl
	IF ERRORLEVEL 6 SET el=2
	IF %el%==2 GOTO err_flutl
	IF ERRORLEVEL 5 SET el=1
	IF %el%==1 GOTO err_flutl
	
	REM  monitor running
	IF ERRORLEVEL 4 SET el=4
	IF %el%==4 GOTO runezld
	IF ERRORLEVEL 3 SET el=3
	IF %el%==3 GOTO runezld
	IF ERRORLEVEL 2 SET el=2
	IF %el%==2 GOTO runezld
	IF ERRORLEVEL 1 SET el=1
	IF %el%==1 GOTO runezld

	REM Nothing seems to be happening on the COM ports:
	IF ERRORLEVEL 0 SET el=0
	IF %el%==0 GOTO bummer
	GOTO end

	REM runezld is the non-error path.
:runezld
	REM If the command line COM port is 0, just use %el%
	IF %1==0 GOTO runezld1
	REM If the command line COM port is the same as %el%, all is well.
	IF %el%==%1 GOTO runezld1
	REM Otherwise, there is confusion. Leave!
	GOTO err_cport

	REM At runezld1 because monitor is available and com port %el is
	REM per command line, continue with loading and running FLASHUTB.EXE
:runezld1
	echo Wait while EZLD installs flash utility to DSP memory
	REM Load FLASHUTB.EXE to DSP with EZLD, COM port %1, and run ('g'):
	@echo on
	ezld %el% flashutb.exe g
	@echo off

	REM Now use FLASHUTB to load the hex file to bank 1 using XFLASH1
	REM Com port is %el%, flash bank is 1, hex file is %2 and confirms are used
	@echo on
	xflash1 %el% 1 %2 0
	@echo off
	REM The load is finished, or errors were noted by xflash1
    goto end

    REM --------------------------------------------------------------
    REM -------------------  sub-routines ----------------------------
	
:err_flutl
	echo Error: The Flash utility apparently is running.
	echo This is not expected.
	echo Do a reset with JP1 open and then run this FL1B.BAT again.
	echo FL1B is aborting
	GOTO end
 
:err_uhf3
	echo Error: UHF3 is still running in DSP memory.
	echo Do a reset with JP1 open and then run this FL1B.BAT again.
	echo FL1B is aborting.
	GOTO end
 
:err_cport
	echo COM port with Monitor is %el%. Command line COM port was %1.
	echo Aborting FL1B.BAT because of discrepancy.
	GOTO splash  
 
:bummer
	echo No COM ports were found, check cable, power to DSPX etc
	echo reset the interface or cycle the power to insure the DSP10x
	echo is running, and try again.
	GOTO splash
	
:err_bsp
	echo Check your spelling and if the file exists.
	echo If you know the path to the file, the path plus file names
	echo can be used on the command line. Otherwise the directory
	echo of FL1B.BAT (the current directory) is searched.
:splash
	echo ***************************************************************
	echo Command Line is:  FL1B n FILENAME.HEX
 	echo     where n=COM port (1 to 4), or 0 for FL1B to find the port.
 	echo           FILENAME.HEX=Intel hex file, e.g., UHF3X35A.HEX
	echo Files:
	echo    FL1B.BAT, EZLD.COM, XFLASH1.EXE, XFINDMN1.EXE,
	echo    FLASHUTB.EXE and FILENAME.HEX
	echo must be in the current directory. 
	echo ***************************************************************
:end 
